=begin
/****************************************************************************
** $Id: dclock.rb,v 1.1.1.1 2002/12/22 14:19:51 taka-hr Exp $
**
** Copyright (C) 1992-2000 Troll Tech AS.  All rights reserved.
**
** This file is part of an example program for Qt.  This example
** program may be used, distributed and modified without limitation.
**
*****************************************************************************/
=end
require "qte"
include Qte
require "qpe"
include Qpe
require "dclock_lib.rb"

    a = QPEApplication.new( [$0]+ARGV )
    clock = DigitalClock.new(8)
    clock.resize( 170, 80 )
    a.showMainWidget( clock )
    a.exec()

